#!/bin/sh

sudo apt-get install -y \
    autoconf \
    bison \
    cmake \
    gcc \
    libmodule-scandeps-perl \
    libparse-yapp-perl \
    libtool \
    make \
    moreutils \
    perl \
    python-dev \
    python-setuptools \
    python3-dev \
    python3-setuptools \
    swig
